@@ -3,9 +3,7 @@ import logging
 from functools import wraps
 
 
-# Setup logger
-logger = logging.getLogger(__name__)
-logging.basicConfig(level=logging.INFO)
+LOGGER = logging.getLogger(__name__)
 
 
 def timeit_log(func):
@@ -14,7 +12,7 @@ def timeit_log(func):
         start = time.perf_counter()
         result = func(*args, **kwargs)
         duration = time.perf_counter() - start
-        logger.info(f"[{func.__name__}] executed in {duration:.4f} seconds")
+        LOGGER.info(f"[{func.__name__}] executed in {duration:.4f} seconds")
         return result
 
     return wrapper
